)]}'
{"mistral/workflow/direct_workflow.py":[{"author":{"_account_id":7700,"name":"Nikolay Mahotkin","email":"nikolay.makhotkin@gmail.com","username":"nmakhotkin"},"change_message_id":"eb8fc101e42178d8e492feab3864043dbbfc12e1","unresolved":false,"context_lines":[{"line_number":381,"context_line":"    def _find_task_execution_by_name(self, t_name):"},{"line_number":382,"context_line":"        # Note: in case of \u0027join\u0027 completion check it\u0027s better to initialize"},{"line_number":383,"context_line":"        # the entire task_executions collection to avoid too many DB queries."},{"line_number":384,"context_line":"        in_t_execs \u003d ["},{"line_number":385,"context_line":"            t for t in self.wf_ex.task_executions if t.name \u003d\u003d t_name"},{"line_number":386,"context_line":"        ]"},{"line_number":387,"context_line":""}],"source_content_type":"text/x-python","patch_set":4,"id":"7a8ec9b2_2294ed35","line":384,"range":{"start_line":384,"start_character":8,"end_line":384,"end_character":18},"updated":"2016-09-14 08:05:12.000000000","message":"It seems that naming \u0027in_t_execs\u0027 is obsolete here and we can use just t_execs.","commit_id":"ae56b7844cf165b10ccb520ed5b2383b8e36a104"},{"author":{"_account_id":8731,"name":"Renat Akhmerov","email":"renat.akhmerov@gmail.com","username":"rakhmerov"},"change_message_id":"be149f16fa66f06e3f11da18205c4f974c0cb75d","unresolved":false,"context_lines":[{"line_number":381,"context_line":"    def _find_task_execution_by_name(self, t_name):"},{"line_number":382,"context_line":"        # Note: in case of \u0027join\u0027 completion check it\u0027s better to initialize"},{"line_number":383,"context_line":"        # the entire task_executions collection to avoid too many DB queries."},{"line_number":384,"context_line":"        in_t_execs \u003d ["},{"line_number":385,"context_line":"            t for t in self.wf_ex.task_executions if t.name \u003d\u003d t_name"},{"line_number":386,"context_line":"        ]"},{"line_number":387,"context_line":""}],"source_content_type":"text/x-python","patch_set":4,"id":"7a8ec9b2_fdb54ad0","line":384,"range":{"start_line":384,"start_character":8,"end_line":384,"end_character":18},"in_reply_to":"7a8ec9b2_2294ed35","updated":"2016-09-14 08:23:42.000000000","message":"Yep, thanks.","commit_id":"ae56b7844cf165b10ccb520ed5b2383b8e36a104"},{"author":{"_account_id":7700,"name":"Nikolay Mahotkin","email":"nikolay.makhotkin@gmail.com","username":"nmakhotkin"},"change_message_id":"eb8fc101e42178d8e492feab3864043dbbfc12e1","unresolved":false,"context_lines":[{"line_number":382,"context_line":"        # Note: in case of \u0027join\u0027 completion check it\u0027s better to initialize"},{"line_number":383,"context_line":"        # the entire task_executions collection to avoid too many DB queries."},{"line_number":384,"context_line":"        in_t_execs \u003d ["},{"line_number":385,"context_line":"            t for t in self.wf_ex.task_executions if t.name \u003d\u003d t_name"},{"line_number":386,"context_line":"        ]"},{"line_number":387,"context_line":""},{"line_number":388,"context_line":"        # TODO(rakhmerov): Temporary hack. See the previous comment."}],"source_content_type":"text/x-python","patch_set":4,"id":"7a8ec9b2_e2d84520","line":385,"range":{"start_line":385,"start_character":12,"end_line":385,"end_character":69},"updated":"2016-09-14 08:05:12.000000000","message":"why can\u0027t we use db_api.get_task_executions(**kwargs) here? \n\nI think it can take less time than requesting all task_executions.","commit_id":"ae56b7844cf165b10ccb520ed5b2383b8e36a104"},{"author":{"_account_id":8731,"name":"Renat Akhmerov","email":"renat.akhmerov@gmail.com","username":"rakhmerov"},"change_message_id":"be149f16fa66f06e3f11da18205c4f974c0cb75d","unresolved":false,"context_lines":[{"line_number":382,"context_line":"        # Note: in case of \u0027join\u0027 completion check it\u0027s better to initialize"},{"line_number":383,"context_line":"        # the entire task_executions collection to avoid too many DB queries."},{"line_number":384,"context_line":"        in_t_execs \u003d ["},{"line_number":385,"context_line":"            t for t in self.wf_ex.task_executions if t.name \u003d\u003d t_name"},{"line_number":386,"context_line":"        ]"},{"line_number":387,"context_line":""},{"line_number":388,"context_line":"        # TODO(rakhmerov): Temporary hack. See the previous comment."}],"source_content_type":"text/x-python","patch_set":4,"id":"7a8ec9b2_7da3fa9e","line":385,"range":{"start_line":385,"start_character":12,"end_line":385,"end_character":69},"in_reply_to":"7a8ec9b2_e2d84520","updated":"2016-09-14 08:23:42.000000000","message":"Yes Nikolay, this is correct. I already changed in my local version after making some tests. The thing is that in some case initializing the entire collection is cheaper, but those case are kind of special. For example, when we not too deep but highly parallel joins (e.g. hundreds of tasks joined into one branch).","commit_id":"ae56b7844cf165b10ccb520ed5b2383b8e36a104"}]}
